PyBaccarat: Todo List

PyBaccarat visit the ministry of silly walks

Todo List

Member pybaccarat.playingcards.Shoe.__init__ (self, number_decks=None)

  need a finite limit to number_decks

  need a finite limit to number_decks

Member pybaccarat.playingcards.Shoe.shuffle (self)

  Find a way to attach a user's shuffle method instead of our own default.

  Find a way to attach a user's shuffle method instead of our own default.